==> huaweicloudsdkkafka-3.1.126-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/list_instance_consumer_groups_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstanceConsumerGroupsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'offset': 'str',
        'limit': 'str',
        'group': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'offset': 'offset',
        'limit': 'limit',
        'group': 'group'
    }

    def __init__(self, instance_id=None, offset=None, limit=None, group=None):
        """ListInstanceConsumerGroupsRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID。
        :type instance_id: str
        :param offset: 偏移量，表示从此偏移量开始查询， offset大于等于0。
        :type offset: str
        :param limit: 当次查询返回的最大消费组ID个数，默认值为10，取值范围为1~50。
        :type limit: str
        :param group: 消费组名过滤查询，过滤方式为字段包含过滤。
        :type group: str
        """
        
        

        self._instance_id = None
        self._offset = None
        self._limit = None
        self._group = None
        self.discriminator = None

        self.instance_id = instance_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if group is not None:
            self.group = group

    @property
    def instance_id(self):
        """Gets the instance_id of this ListInstanceConsumerGroupsRequest.

        实例ID。

        :return: The instance_id of this ListInstanceConsumerGroupsRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ListInstanceConsumerGroupsRequest.

        实例ID。

        :param instance_id: The instance_id of this ListInstanceConsumerGroupsRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def offset(self):
        """Gets the offset of this ListInstanceConsumerGroupsRequest.

        偏移量，表示从此偏移量开始查询， offset大于等于0。

        :return: The offset of this ListInstanceConsumerGroupsRequest.
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListInstanceConsumerGroupsRequest.

        偏移量，表示从此偏移量开始查询， offset大于等于0。

        :param offset: The offset of this ListInstanceConsumerGroupsRequest.
        :type offset: str
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListInstanceConsumerGroupsRequest.

        当次查询返回的最大消费组ID个数，默认值为10，取值范围为1~50。

        :return: The limit of this ListInstanceConsumerGroupsRequest.
        :rtype: str
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListInstanceConsumerGroupsRequest.

        当次查询返回的最大消费组ID个数，默认值为10，取值范围为1~50。

        :param limit: The limit of this ListInstanceConsumerGroupsRequest.
        :type limit: str
        """
        self._limit = limit

    @property
    def group(self):
        """Gets the group of this ListInstanceConsumerGroupsRequest.

        消费组名过滤查询，过滤方式为字段包含过滤。

        :return: The group of this ListInstanceConsumerGroupsRequest.
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this ListInstanceConsumerGroupsRequest.

        消费组名过滤查询，过滤方式为字段包含过滤。

        :param group: The group of this ListInstanceConsumerGroupsRequest.
        :type group: str
        """
        self._group = group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstanceConsumerGroupsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.1.151-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/list_instance_consumer_groups_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstanceConsumerGroupsRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'offset': 'str',
        'limit': 'str',
        'group': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'offset': 'offset',
        'limit': 'limit',
        'group': 'group'
    }

    def __init__(self, instance_id=None, offset=None, limit=None, group=None):
        r"""ListInstanceConsumerGroupsRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID。
        :type instance_id: str
        :param offset: 偏移量，表示从此偏移量开始查询， offset大于等于0。
        :type offset: str
        :param limit: 当次查询返回的最大消费组ID个数，默认值为10，取值范围为1~50。
        :type limit: str
        :param group: 消费组名过滤查询，过滤方式为字段包含过滤。
        :type group: str
        """
        
        

        self._instance_id = None
        self._offset = None
        self._limit = None
        self._group = None
        self.discriminator = None

        self.instance_id = instance_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit
        if group is not None:
            self.group = group

    @property
    def instance_id(self):
        r"""Gets the instance_id of this ListInstanceConsumerGroupsRequest.

        实例ID。

        :return: The instance_id of this ListInstanceConsumerGroupsRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        r"""Sets the instance_id of this ListInstanceConsumerGroupsRequest.

        实例ID。

        :param instance_id: The instance_id of this ListInstanceConsumerGroupsRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def offset(self):
        r"""Gets the offset of this ListInstanceConsumerGroupsRequest.

        偏移量，表示从此偏移量开始查询， offset大于等于0。

        :return: The offset of this ListInstanceConsumerGroupsRequest.
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        r"""Sets the offset of this ListInstanceConsumerGroupsRequest.

        偏移量，表示从此偏移量开始查询， offset大于等于0。

        :param offset: The offset of this ListInstanceConsumerGroupsRequest.
        :type offset: str
        """
        self._offset = offset

    @property
    def limit(self):
        r"""Gets the limit of this ListInstanceConsumerGroupsRequest.

        当次查询返回的最大消费组ID个数，默认值为10，取值范围为1~50。

        :return: The limit of this ListInstanceConsumerGroupsRequest.
        :rtype: str
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        r"""Sets the limit of this ListInstanceConsumerGroupsRequest.

        当次查询返回的最大消费组ID个数，默认值为10，取值范围为1~50。

        :param limit: The limit of this ListInstanceConsumerGroupsRequest.
        :type limit: str
        """
        self._limit = limit

    @property
    def group(self):
        r"""Gets the group of this ListInstanceConsumerGroupsRequest.

        消费组名过滤查询，过滤方式为字段包含过滤。

        :return: The group of this ListInstanceConsumerGroupsRequest.
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        r"""Sets the group of this ListInstanceConsumerGroupsRequest.

        消费组名过滤查询，过滤方式为字段包含过滤。

        :param group: The group of this ListInstanceConsumerGroupsRequest.
        :type group: str
        """
        self._group = group

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstanceConsumerGroupsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
